
.. _HydPy-T:

HydPy-T (TESTING)
=================

The HydPy-T base model is thought for providing simple test models to
test and explain the functionality of some framework features.   So far,
three applications models for testing numerical integration algorithms
are available.

Base model:

.. toctree::
   :maxdepth: 1

   test

Application model:

.. toctree::

   test_v1
   test_v2
   test_v3
